C.J. Collier
/
Protobuf-0.07
/
SECURITY.md
Security Policy
Reporting a Vulnerability
If you discover a security vulnerability in this project, please report it to the maintainer:
We take security issues seriously and will respond to reports as quickly as possible.